
# Guide ScoDoc pour le ou la responsable de formation

Cette partie s'adresse plutôt aux responsables de formation (cheffes ou chefs de
département IUT, responsable de filières, ...). Nous allons apprendre à:

* définir une formation (saisie du programme pédagogique définissant les modules)

* mettre en place un semestre (ou session) de formation

* inscrire des étudiants à un semestre de formation

## Définir un programme pédagogique

Le programme pédagogique d'une formation défini les unités d'enseignement; il
est destiné à être utilisé par plusieurs sessions de formation (semestres). On
doit apporter un soin particulier à la définition du programme, et éviter de le
modifier une fois que des semestres sont créés (il est toutefois possible d'en
créer de nouvelles *versions* pour permettre des modifications ultérieures sans
affecter les semestres achevés: voir [VersionProgrammes](VersionProgrammes.md)).

On définira en général dans le programme l'ensemble des enseignements d'un
diplôme (les 4 semestres d'un DUT par exemple). C'est dans une phase ultérieure
que l'on mettra en place les différents semestres.

Les programmes pédagogiques ScoDoc sont structurés en Unités d'Enseignements
(UE), Matières et Modules. Un module appartient forcément à une matière, qui
appartient elle même à une UE. Les modules (déclinés en *ressources*, *SAÉs* en
BUT) représentent les cours ("mathématique", "anglais", ...) et sont associés à
un volume horaire (cours/TD/TP) et à un coefficient: chaque module produit une
note moyenne (en général obtenue à travers plusieurs *évaluations* ou
contrôles). La note moyenne d'une UE est obtenue en calculant une moyenne
pondérée par les coefficients des notes moyennes de modules.

🚸 En BUT, c'est un peu différent, puisque les modules ont une note *pour chaque
UE*: la moyenne d'un module n'est pas définie. Voir [BUT](BUT.md)

Les matières n'ont pas d'autre utilité que d'aider à structurer le programme.
Par exemple, on pourrait définir dans un programme une matière "Sciences"
réunissant les modules de "mathématiques" et de "physique". Les matières n'ont
pas de coefficient. Si l'on ne souhaite pas utiliser de matière, il suffit d'en
créer une pour chaque module avec le même nom, ou au contraire (plus simplement)
de créer une matière par UE et d'y placer tous les modules.

Les UE jouent un rôle particulier dans l'évaluation. En effet, selon les règles
du LMD, les UE sont *capitalisables* (voir
[CapitalisationUE](CapitalisationUE.md)). De plus, l'obtention de droit des
semestres d'un DUT est soumise à une moyenne supérieure à 8/20 dans chacune des
UE.

Notons qu'une UE ne possède pas de coefficient. Le coefficient d'une UE n'est
autre que la somme des coefficient des modules qui composent cette UE. Par
conséquent, le coefficient d'UE est potentiellement variable d'un étudiant à
l'autre, si les étudiants ne sont pas inscrits aux mêmes modules (options ou
parcours).

Vous trouverez plus d'informations sur la définition des programmes sur la page
[VersionProgrammes](VersionProgrammes.md).

## Versions des programmes de formation

Chaque semestre ("FormSemestre" dans le jargon ScoDoc) se réfère à un programme
pédagogique, appelé sa *formation*. cette formation définit l'ensemble des UE et
modules, leurs intitulés, et leurs coefficients et ECTS.

Les programmes sont le plus souvent adaptés localement, et peuvent varier d'une
année sur l'autre. Lorsqu'une formation est modifié (par exemple, un changement
de coefficient), ScoDoc doit recalculer l'ensemble des notes de tous les
semestres utilisant cette formation. De même, si un intitulé change, il faut
re-générer les bulletins et procès-verbaux. On conçoit donc que la modification
d'une formation ne s'aborde pas à la légère. ScoDoc empêche d'ailleurs toute
modification d'une formation (ou partie de, selon les cas) lorsqu'un semestre a
été verrouillé (ce qui indique en général qu'il est achevé et que l'on souhaite
conserver ses données et résultats inchangés pour utilisation future dans des
jurys ou avis).

Si vous devez modifier une formation pour la nouvelle année scolaire, vous
pouvez créer une nouvelle version d'une formation existante afin d'éviter
d'avoir à saisir de nouveau l'ensemble des éléments. Il arrive même que, l'année
scolaire déjà commencée, on se rende compte que l'on doit modifier la formation
d'un semestre en cours (bien sûr, cela ne devrait pas arriver, les modalités
d'évaluation étant souvent votées par des instances officielles avant le début
de l'année, mais le monde n'est pas parfait et de petites corrections sont
parfois nécessaires). Dans ce cas, ScoDoc vous permet d'associer un ou plusieurs
semestres existants dans une formation à une nouvelle version de celle-ci, créée
par copie.

![menu formsemestre](fig/menu-formsemestre-assoc.png)

La figure suivante montre la distinction entre formations et semestres, et les opérations possibles:

![menu formsemestre](fig/formations_versions_association.jpg)

![association nouvelle version](fig/sem-assoc-formation.png)

### Changement de la formation d'un semestre

Il peut arriver que l'on ai créé deux versions de formations, qui sont encore
identique, et que l'on souhaite rattacher un formsemestre de l'une à l'autre.
C'est possible, à condition que les deux formations soient vraiment identiques
(mêmes UEs, titres, coefficients, etc). Le lien est accessible en bas de la page
"Associer à une nouvelle version du programme" mentionnée ci-dessus.

![change formation](fig/sem-change-formation.png)

## Créer un semestre de formation

Pour créer un semestre de formation, on va partir d'un programme pédagogique
donné et y choisir un (sous)ensemble de modules. Le semestre sera associé à une
date de début, une date de fin, et un responsable (*directeur des études* dans
le langage IUT).

* Options de paramétrage d'un semestre: [Paramétrage Semestre](ParametrageSemestre.md)

## Inscrire des étudiants

* [Importer des listes d'étudiants](ImportationEtuds.md) (en début d'année ou de semestre)

* [Synchroniser avec une étape Apogée](SynchroApogee.md)

* [Vérifier les codes NIP](VerifCodeNIP.md)

* [Associer des photos aux étudiants](GestionPhotos.md)

* [Données sur scolarité antérieure et admission](DonneesAdmissions.md)

## Suivi de la Scolarité

* [Récapitulatif des opérations en fin de semestre et début du suivant](TransitionSemestre.md)

* [Note sur la capitalisation des UE](CapitalisationUE.md)

* [Note sur la compensation des semestres](CompensationSemestre.md) (DUT)

## Échanges de programmes pédagogiques entre établissements

ScoDoc permet d'exporter et d'importer des programmes pédagogiques: voir des
fichiers sur la page
[Exemples Programmes Pédagogiques](ExemplesProgrammesPedagogiques.md)

!!! note "Voir aussi"

    - [Édition des programmes de formation](VersionProgrammes.md)
    - [Guide utilisateur](GuideUtilisateur.md)
    - [Modélisation BUT: exemple complet](BUTExempleInfo.md)
    - [Tutoriels vidéo](https://www.youtube.com/channel/UCb0JYCBRi0CsE4XFp4ByhXg)
          - [Gestion des UE Bonus](https://www.youtube.com/watch?v=SVbjuDpq-lI)
          - [Mise en place des parcours BUT](https://www.youtube.com/watch?v=OnuOXJo-3ro)
          - [Saisie des codes Apogée](https://www.youtube.com/watch?v=MW0nNhbBjDM)
          - [Du DUT au BUT: comment transformer un programme](https://www.youtube.com/watch?v=9HizGTvYgck)
    - [FAQ](FAQ.md)
    - [Contacts](Contact.md)
